@@ -150,16 +150,20 @@ class SourceEditAPIView(ThemePackageMixin, UpdateEditableMixin,
             dest.write(block_text)
 
     def update(self, request, *args, **kwargs):
+        #pylint:disable=unused-argument,unused-variable
         #pylint:disable=too-many-locals,too-many-nested-blocks
         #pylint:disable=too-many-statements
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
         element_id = self.kwargs.get('path')
         element_text = serializer.validated_data.get('text')
+        hints = serializer.validated_data.get('hints', [])
+        LOGGER.debug("update '%s' with \"%s\" (hints=%s)",
+            element_id, element_text, hints)
         found = False
         dest = None
         dest_hint = None
-        for hint in serializer.validated_data.get('hints', []):
+        for hint in hints:
             relative_path = hint.get('name')
             template_path = get_template_path(relative_path=relative_path)
             dest = six.StringIO()
@@ -315,7 +319,7 @@ class SourceEditAPIView(ThemePackageMixin, UpdateEditableMixin,
                             template_path=template_path)
                         buffered_tokens = []
 
-            except UnicodeDecodeError as err:
+            except UnicodeDecodeError:
                 LOGGER.warning("%s: Templates can only be constructed "
                     "from unicode or UTF-8 strings.", template_path)
             dest = dest.getvalue()
@@ -338,6 +342,15 @@ class SourceEditAPIView(ThemePackageMixin, UpdateEditableMixin,
                 break
         if not found:
             raise Http404()
+
+        # clear template loaders caches
+        engines = _engine_list(using=None)
+        for engine in engines:
+            try:
+                engine.env.cache.clear()
+            except AttributeError:
+                pass
+
         return Response(self.get_serializer().to_representation({
                 'text': dest,
                 'hints': [dest_hint]
