@@ -1,4 +1,4 @@
-# Copyright (c) 2021, Djaodjin Inc.
+# Copyright (c) 2022, Djaodjin Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@ from collections import OrderedDict
 
 from django.contrib.auth import get_user_model
 from django.db import IntegrityError, models, transaction
-from django.db.models import Max
+from django.db.models import Max, Q
 from django.template.defaultfilters import slugify
 from django.utils.translation import ugettext_lazy as _
 from rest_framework.exceptions import ValidationError
@@ -42,7 +42,7 @@ LOGGER = logging.getLogger(__name__)
 
 
 def get_extra_field_class():
-    extra_class = settings._SETTINGS.get('EXTRA_FIELD')
+    extra_class = settings.EXTRA_FIELD
     if extra_class is None:
         extra_class = models.TextField
     elif isinstance(extra_class, str):
@@ -122,9 +122,10 @@ class RelationShip(models.Model):
 
 class PageElementQuerySet(models.QuerySet):
 
-
-    def build_content_tree(self, prefix="", cut=None):
-        return build_content_tree(roots=self, prefix=prefix, cut=cut)
+    def build_content_tree(self, prefix="", cut=None,
+                           visibility=None, accounts=None):
+        return build_content_tree(roots=self, prefix=prefix,
+            cut=cut, visibility=visibility, accounts=accounts)
 
 
 class PageElementManager(models.Manager):
@@ -132,11 +133,28 @@ class PageElementManager(models.Manager):
     def get_queryset(self):
         return PageElementQuerySet(self.model, using=self._db)
 
-    def get_roots(self):
-        return self.all().extra(where=[
+    def get_roots(self, visibility=None, accounts=None):
+        filtered_in = None
+        if visibility:
+            for visible in visibility:
+                visibility_q = Q(extra__contains=visible)
+                if filtered_in:
+                    filtered_in |= visibility_q
+                else:
+                    filtered_in = visibility_q
+        if accounts:
+            accounts_q = Q(account__slug__in=accounts)
+            if filtered_in:
+                filtered_in |= accounts_q
+            else:
+                filtered_in = accounts_q
+
+        queryset = (self.filter(filtered_in)
+            if filtered_in else self.all()).extra(where=[
             '(SELECT COUNT(*) FROM pages_relationship'\
             ' WHERE pages_relationship.dest_element_id = pages_pageelement.id)'\
             ' = 0'])
+        return queryset
 
     def get_leafs(self):
         return self.all().extra(where=[
@@ -348,7 +366,7 @@ class Follow(models.Model):
         unique_together = (('user', 'element'),)
 
     def __str__(self):
-        return u'%s follows %s' % (self.user, self.element)
+        return '%s follows %s' % (self.user, self.element)
 
 
 class VoteManager(models.Manager):
@@ -384,8 +402,8 @@ class Vote(models.Model):
     UP_VOTE = 1
     DOWN_VOTE = -1
     SCORES = (
-        (UP_VOTE, u'+1'),
-        (DOWN_VOTE, u'-1'),
+        (UP_VOTE, '+1'),
+        (DOWN_VOTE, '-1'),
     )
 
     created_at = models.DateTimeField(editable=False, auto_now_add=True)
@@ -399,7 +417,7 @@ class Vote(models.Model):
         unique_together = (('user', 'element'),)
 
     def __str__(self):
-        return u'%s: %s on %s' % (self.user, self.vote, self.element)
+        return "%s: %s on %s" % (self.user, self.vote, self.element)
 
     def is_upvote(self):
         return self.vote == self.UP_VOTE
@@ -459,7 +477,8 @@ class ThemePackage(models.Model):
         return self.name
 
 
-def build_content_tree(roots=None, prefix=None, cut=None):
+def build_content_tree(roots=None, prefix=None, cut=None,
+                       visibility=None, accounts=None):
     """
     Returns a content tree from a list of roots.
 
@@ -485,7 +504,9 @@ def build_content_tree(roots=None, prefix=None, cut=None):
     # We use a breadth-first search algorithm here such as to minimize
     # the number of queries to the database.
     if roots is None:
-        roots = PageElement.objects.get_roots()
+        roots = PageElement.objects.get_roots(
+            visibility=visibility, accounts=accounts).order_by(
+            '-account_id', 'title')
         if prefix and prefix != '/':
             LOGGER.warning("[build_content_tree] prefix=%s but no roots"\
                 " were defined", prefix)
@@ -501,6 +522,22 @@ def build_content_tree(roots=None, prefix=None, cut=None):
         prefix = '/%s' % prefix
     if prefix.endswith("/"):
         prefix = prefix[:-1]
+    filtered_in = None
+    if visibility:
+        for visible in visibility:
+            visibility_q = Q(dest_element__extra__contains=visible)
+            if filtered_in:
+                filtered_in |= visibility_q
+            else:
+                filtered_in = visibility_q
+    if accounts:
+        accounts_q = Q(dest_element__account__slug__in=accounts)
+        if filtered_in:
+            filtered_in |= accounts_q
+        else:
+            filtered_in = accounts_q
+    edges_qs = (RelationShip.objects.filter(filtered_in)
+        if filtered_in else  RelationShip.objects.all())
 
     results = OrderedDict()
     pks_to_leafs = {}
@@ -512,12 +549,14 @@ def build_content_tree(roots=None, prefix=None, cut=None):
             title = root.title
             picture = root.picture
             extra = root.extra
+            text = root.text
         else:
             slug = root.get('slug', root.get('dest_element__slug'))
             orig_element_id = root.get('dest_element__pk')
             title = root.get('dest_element__title')
             picture = root.get('dest_element__picture')
             extra = root.get('dest_element__extra')
+            text = root.get('dest_element__text', None)
         leaf_slug = '/%s' % slug
         if prefix.endswith(leaf_slug):
             # Workaround because we sometimes pass a prefix and sometimes
@@ -529,9 +568,13 @@ def build_content_tree(roots=None, prefix=None, cut=None):
             extra = json.loads(extra)
         except (TypeError, ValueError):
             pass
-        result_node = {'title': title}
+        result_node = {'slug': slug, 'title': title}
+        if picture:
+            result_node.update({'picture': picture})
         if extra:
             result_node.update({'extra': extra})
+        if text:
+            result_node.update({'text': text})
         pks_to_leafs[orig_element_id] = {
             'path': base,
             'node': (result_node, OrderedDict())
@@ -541,7 +584,7 @@ def build_content_tree(roots=None, prefix=None, cut=None):
             roots_after_cut += [root]
 
     args = tuple([])
-    edges = RelationShip.objects.filter(
+    edges = edges_qs.filter(
         orig_element__in=roots_after_cut).values(
         'orig_element_id', 'dest_element_id', 'rank', 'dest_element__slug',
         'dest_element__extra', 'dest_element__picture', 'dest_element__title',
@@ -560,7 +603,7 @@ def build_content_tree(roots=None, prefix=None, cut=None):
                 extra = json.loads(extra)
             except (TypeError, ValueError):
                 pass
-            result_node = {'title': title}
+            result_node = {'slug': slug, 'title': title}
             if picture:
                 result_node.update({'picture': picture})
             if extra:
@@ -577,7 +620,7 @@ def build_content_tree(roots=None, prefix=None, cut=None):
                 }
         pks_to_leafs = next_pks_to_leafs
         next_pks_to_leafs = {}
-        edges = RelationShip.objects.filter(
+        edges = edges_qs.filter(
             orig_element_id__in=pks_to_leafs.keys()).values(
             'orig_element_id', 'dest_element_id', 'rank', 'dest_element__slug',
             'dest_element__extra', 'dest_element__picture',
@@ -585,20 +628,28 @@ def build_content_tree(roots=None, prefix=None, cut=None):
     return results
 
 
-def flatten_content_tree(roots, depth=0):
+def flatten_content_tree(roots, sort_by_key=True, depth=0):
     """
     Transforms a tree into a list with ``indent`` as the depth of a node
     in the original tree.
     """
     results = []
-    for key, values in six.iteritems(roots):
+    children = six.iteritems(roots)
+    if sort_by_key:
+        children = sorted(children,
+            key=lambda node: (
+                node[1][0].get('rank', 0)
+                if node[1][0].get('rank') is not None else 0,
+                node[1][0].get('title', "")))
+    for key, values in children:
         elem, nodes = values
         elem.update({
             'path': key,
             'indent': depth
         })
         results += [elem]
-        results += flatten_content_tree(nodes, depth=depth + 1)
+        results += flatten_content_tree(nodes,
+            sort_by_key=sort_by_key, depth=depth + 1)
     return results
 
 
