@@ -1,4 +1,4 @@
-# Copyright (c) 2021, Djaodjin Inc.
+# Copyright (c) 2022, Djaodjin Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -124,7 +124,8 @@ class NodeElementSerializer(serializers.ModelSerializer):
                   'title', 'picture', 'extra')
         read_only_fields = ('slug', 'path', 'indent', 'account')
 
-    def get_extra(self, obj):
+    @staticmethod
+    def get_extra(obj):
         try:
             return obj.get('extra', {})
         except AttributeError:
@@ -135,7 +136,8 @@ class NodeElementSerializer(serializers.ModelSerializer):
             pass
         return {}
 
-    def get_indent(self, obj):
+    @staticmethod
+    def get_indent(obj):
         try:
             return obj.get('indent', 0)
         except AttributeError:
@@ -146,7 +148,8 @@ class NodeElementSerializer(serializers.ModelSerializer):
             pass
         return 0
 
-    def get_path(self, obj):
+    @staticmethod
+    def get_path(obj):
         try:
             return obj.get('path', None)
         except AttributeError:
@@ -163,7 +166,7 @@ class PageElementSerializer(serializers.ModelSerializer):
     Serializes a PageElement.
     """
 
-    path = serializers.CharField(required=False, allow_null=True)
+    path = serializers.SerializerMethodField()
     slug = serializers.SlugField(required=False,
         help_text=_("Unique identifier that can be used in URL paths"))
     account = serializers.SlugRelatedField(slug_field='slug',
@@ -194,28 +197,34 @@ class PageElementSerializer(serializers.ModelSerializer):
             'nb_upvotes', 'nb_followers', 'upvote', 'follow',
             'count', 'results')
 
-    def get_extra(self, obj):
-        if not isinstance(obj.extra, dict):
+    @staticmethod
+    def get_extra(obj):
+        try:
+            extra = obj.extra
+        except AttributeError:
+            extra = obj.get('extra', {})
+        if not isinstance(extra, dict):
             try:
-                return json.loads(obj.extra)
+                return json.loads(extra)
             except (TypeError, ValueError):
                 pass
-        return obj.extra
+        return extra
 
     def get_upvote(self, data):
         request = self.context.get('request')
         if request and is_authenticated(request):
-            vote = Vote.objects.filter(
-                user=request.user, element=data).first()
-            return vote and vote.vote == Vote.UP_VOTE
+            if isinstance(data, PageElement):
+                vote = Vote.objects.filter(
+                    user=request.user, element=data).first()
+                return vote and vote.vote == Vote.UP_VOTE
         return None
 
     def get_follow(self, data):
         request = self.context.get('request')
         if request and is_authenticated(request):
-            follow = Follow.objects.filter(
-                user=request.user, element=data).first()
-            return follow is not None
+            if isinstance(data, PageElement):
+                return Follow.objects.filter(
+                    user=request.user, element=data).exists()
         return None
 
     def get_path(self, obj):
@@ -227,7 +236,12 @@ class PageElementSerializer(serializers.ModelSerializer):
                     [parent.slug for parent in parents[0][:-1]])
                 if prefix:
                     prefix = "/" + prefix
-        return "%s/%s" % (prefix, obj.slug)
+                prefix = prefix + "/"
+        try:
+            slug = obj.slug
+        except AttributeError:
+            slug = obj.get('slug', "")
+        return prefix + slug
 
 
 class PageElementTagSerializer(serializers.ModelSerializer):
