@@ -1,4 +1,4 @@
-# Copyright (c) 2021, Djaodjin Inc.
+# Copyright (c) 2022, Djaodjin Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,5 @@ from pages.views.pages import EditView
 
 urlpatterns = [
     url(r'^api/', include('pages.urls.api')),
-    url(r'^', include('pages.urls.editables')),
-    url(r'^', include('pages.urls.themes')),
+    url(r'^', include('pages.urls.views')),
 ]
